# Table of Contents

- [user-profile](<./user-profile.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [User Profile](<./User-Profile.md>)
  - [Updating Your User Profile](<./User-Profile/Updating-Your-User-Profile.md>)
  - [Changing Your Password](<./User-Profile/Changing-Your-Password.md>)
  - [Resetting Your Password](<./User-Profile/Resetting-Your-Password.md>)
